# XRIPL

XRIPL (C22023): X-Ray Radiographic Image Processing Library

Pawel M. Kozlowski 2018-10-19


XRIPL (read as "zripple") is a library of tools for processing x-ray
radiographs and extracting contours of interest within the image using
computer vision techniques. Features include spatial calibration, denoising,
background and attenuation correction through pseudo-flatfielding, watershed
segmentation, contour processing, and visualization. The details of the XRIPL
analysis pipeline are published in the Proceedings of the 23rd Topical
Conference on High-Temperature Plasma Diagnostics Proceedings [1].

[1] P. M. Kozlowski, Y. Kim, B. M. Haines, H. F. Robey, T. J. Murphy,
H. M. Johns, and T. S. Perry. Use of Computer Vision for analysis of image
data sets from high temperature plasma experiments. Review of Scientific
Instruments 92, 033532 (2021) https://doi.org/10.1063/5.0040285

## Installation
Detailed installation instructions can be found [here]().

## License
XRIPL is released under a [3-clause BSD license]().

## Citing XRIPL
If you use XRIPL in your work, please follow the best practices for citing
XRIPL which can be found [here]().

## Acknowledgements
Development of Fiducia was supported by the U.S. Department of Energy, and
the NNSA.
